@@ -40,13 +40,24 @@ check_new_db_is_empty(migratorContext *ctx)
 {
 	int			dbnum;
 	bool		found = false;
-
+	
 	get_db_and_rel_infos(ctx, &ctx->new.dbarr, CLUSTER_NEW);
 
 	for (dbnum = 0; dbnum < ctx->new.dbarr.ndbs; dbnum++)
 	{
-		if (ctx->new.dbarr.dbs[dbnum].rel_arr.nrels != 0)
-			found = true;
+		int			relnum;
+		RelInfoArr	*rel_arr = &ctx->new.dbarr.dbs[dbnum].rel_arr;
+		
+		for (relnum = 0; relnum < rel_arr->nrels;
+			 relnum++)
+		{
+			/* pg_largeobject and its index should be skipped */
+			if (strcmp(rel_arr->rels[relnum].nspname, "pg_catalog") != 0)
+			{
+				found = true;
+				break;
+			}
+		}
 	}
 
 	dbarr_free(&ctx->new.dbarr);
@@ -326,24 +337,32 @@ get_rel_infos(migratorContext *ctx, const char *db_name, RelInfoArr *relarr,
 	int			i_reltoastrelid = -1;
 	char	    query[QUERY_ALLOC];
 
+	/*
+	 *	pg_largeobject contains user data that does not appear
+	 *	the pg_dumpall --schema-only output, so we have to migrate
+	 *	that system table heap and index.  Ideally we could just get the
+	 *  relfilenode from template1 but pg_largeobject_loid_pn_index's
+	 *	relfilenode can change if the table was reindexed so we
+	 *	get the relfilenode for each database and migrate it
+	 *	as a normal user table.
+	 */
+	 
 	snprintf(query, sizeof(query),
 				"SELECT DISTINCT c.oid, n.nspname, c.relname, "
 				"	c.relfilenode, c.reltoastrelid, "
-				"	t.spclocation,n.nspname "
+				"	t.spclocation "
 				"FROM pg_catalog.pg_class c JOIN "
 				"		pg_catalog.pg_namespace n "
 				"	ON c.relnamespace = n.oid "
 				"   LEFT OUTER JOIN pg_catalog.pg_tablespace t "
 				"	ON c.reltablespace = t.oid "
-				"WHERE relnamespace NOT IN "
-				"	( "
-				"		SELECT oid "
-				"		FROM pg_catalog.pg_namespace "
-				"		WHERE nspname IN "
-				"			('pg_catalog', 'information_schema') "
-				"	) "
+				"WHERE (( n.nspname NOT IN ('pg_catalog', 'information_schema') "
 				"	AND c.oid >= "
 				STRINGIFY(FirstNormalObjectId) " "
+				"	) OR ( "
+				"	n.nspname = 'pg_catalog' "
+				"	AND (relname = 'pg_largeobject' OR "
+				"		 relname = 'pg_largeobject_loid_pn_index') )) "
 				"	AND "
 				"	(relkind = 'r' OR relkind = 't' OR "
 				"	 relkind = 'i'%s)%s"
@@ -393,13 +412,12 @@ get_rel_infos(migratorContext *ctx, const char *db_name, RelInfoArr *relarr,
 
 	relinfos = (RelInfo *) pg_malloc(ctx, sizeof(RelInfo) * ntups);
 
-	i_spclocation = PQfnumber(res, "spclocation");
+	i_oid = PQfnumber(res, "oid");
 	i_nspname = PQfnumber(res, "nspname");
 	i_relname = PQfnumber(res, "relname");
-	i_oid = PQfnumber(res, "oid");
 	i_relfilenode = PQfnumber(res, "relfilenode");
 	i_reltoastrelid = PQfnumber(res, "reltoastrelid");
-	i_nspname = PQfnumber(res, "nspname");
+	i_spclocation = PQfnumber(res, "spclocation");
 
 	for (relnum = 0; relnum < ntups; relnum++)
 	{
