@@ -57,8 +57,7 @@ main(int argc, char **argv)
 
 	set_locale_and_encoding(&ctx, CLUSTER_OLD);
 	
-	/* Get the pg_database and pg_largeobject relation OID's */
-	get_misc_relfilenodes(&ctx, CLUSTER_OLD);
+	get_pg_database_relfilenode(&ctx, CLUSTER_OLD);
 
 	/* Extract a list of databases and tables from the old cluster */
 	get_db_and_rel_infos(&ctx, &ctx.old.dbarr, CLUSTER_OLD);
@@ -155,7 +154,7 @@ main(int argc, char **argv)
 			  ctx.new.bindir, ctx.new.port, ctx.logfile);
 	check_ok(&ctx);
 
-	get_misc_relfilenodes(&ctx, CLUSTER_NEW);
+	get_pg_database_relfilenode(&ctx, CLUSTER_NEW);
 
 	stop_postmaster(&ctx, false, false);
 
@@ -581,7 +580,7 @@ check_cluster_versions(migratorContext *ctx)
 	else
 	{
 		if (GET_MAJOR_VERSION(ctx->new.pg_version) < 803)
-			pg_log(ctx, PG_FATAL, "This utility can only upgrade to EnterpriseDB Advanced Server version 8.3 and later.\n");
+			pg_log(ctx, PG_FATAL, "This utility can only upgrade to EnterpriseDB Postgres Plus Advanced Server\nversion 8.3 and later.\n");
 	}
 
 	/*
