@@ -2,7 +2,7 @@
  *	pg_migrator.h
  */
 
-#define	PG_MIGRATOR_VERSION	"8.4.4"
+#define	PG_MIGRATOR_VERSION	"8.4.5"
 
 #include "postgres.h"
 
@@ -208,11 +208,9 @@ typedef struct
 	uint32		pg_version;		/* PG_VERSION of cluster */
 	char	   *pg_version_str;	/* string PG_VERSION of cluster */
 	Oid			pg_database_oid;		/* OID of pg_database relation */
-	Oid			pg_largeobject_oid;	/* OID of pg_largeobject relation */
-	Oid			pg_largeobject_index_oid;	/* OID of pg_largeobject index */
 	char	   *libpath;	/* pathname for cluster's pkglibdir */
 	/* EDB AS is PG 8.2 with 8.3 enhancements backpatched. */
-	bool		is_edb_as;	/* is EnterpriseDB Advanced Server? */
+	bool		is_edb_as;	/* EnterpriseDB's Postgres Plus Advanced Server? */
 } ClusterInfo;
 
 
@@ -341,7 +339,7 @@ void		parseCommandLine(migratorContext *ctx, int argc, char *argv[]);
 /* relfilenode.c */
 
 void		reserve_relfilenode_names(migratorContext *ctx);
-void		get_misc_relfilenodes(migratorContext *ctx, Cluster whichCluster);
+void		get_pg_database_relfilenode(migratorContext *ctx, Cluster whichCluster);
 void		get_tablespace_paths(migratorContext *ctx);
 void		rename_tablespaces(migratorContext *ctx);
 PGresult   *getDatabaseOIDs(PGconn *conn);
