@@ -168,8 +168,6 @@ transfer_all_new_dbs(migratorContext *ctx, DbInfoArr *olddb_arr,
 	{
 		DbInfo	   *new_db = &newdb_arr->dbs[dbnum];
 		DbInfo	   *old_db = dbarr_lookup_db(olddb_arr, new_db->db_name);
-		char		old_file[MAXPGPATH];
-		char		new_file[MAXPGPATH];
 		FileNameMap *mappings;
 		int			n_maps;
 		pageCnvCtx *pageConverter = NULL;
@@ -189,30 +187,6 @@ transfer_all_new_dbs(migratorContext *ctx, DbInfoArr *olddb_arr,
 
 			pg_free(mappings);
 		}
-		
-		/*
-		 * The pg_largeobject system table is treated as a user table.
-		 * Since we already know its OID we simply link it
-		 */
-		snprintf(old_file, sizeof(old_file), "%s/base/%u/%u", old_pgdata,
-				 old_db->db_oid, ctx->old.pg_largeobject_oid);
-		snprintf(new_file, sizeof(new_file), "%s/base/%u/%u", new_pgdata,
-				 new_db->db_oid, ctx->new.pg_largeobject_oid);
-
-		unlink(new_file);
-		transfer_relfile(ctx, pageConverter, old_file, new_file, "pg_catalog",
-					"pg_largeobject", "pg_catalog", "pg_largeobject");
-
-		/* do the pg_largeobject index too */
-		snprintf(old_file, sizeof(old_file), "%s/base/%u/%u", old_pgdata,
-				 old_db->db_oid, ctx->old.pg_largeobject_index_oid);
-		snprintf(new_file, sizeof(new_file), "%s/base/%u/%u", new_pgdata,
-				 new_db->db_oid, ctx->new.pg_largeobject_index_oid);
-
-		unlink(new_file);
-		transfer_relfile(ctx, pageConverter, old_file, new_file, "pg_catalog",
-					"pg_largeobject_loid_pn_index", "pg_catalog",
-					"pg_largeobject_loid_pn_index");
 	}
 
 	return msg;
@@ -220,19 +194,19 @@ transfer_all_new_dbs(migratorContext *ctx, DbInfoArr *olddb_arr,
 
 
 /*
- * get_misc_relfilenodes()
+ * get_pg_database_relfilenode()
  *
  *	Retrieves the relfilenode for a few system-catalog tables.	We need these
  *	relfilenodes later in the upgrade process.
  */
 void
-get_misc_relfilenodes(migratorContext *ctx, Cluster whichCluster)
+get_pg_database_relfilenode(migratorContext *ctx, Cluster whichCluster)
 {
 	PGconn	   *conn = connectToServer(ctx, "template1", whichCluster);
 	PGresult   *res;
 	int			i_relfile;
 
-	prep_status(ctx, "Getting pg_database and pg_largeobject relfilenodes");
+	prep_status(ctx, "Getting pg_database relfilenode");
 
 	res = executeQueryOrDie(ctx, conn,
 							"SELECT c.relname, c.relfilenode "
@@ -240,24 +214,14 @@ get_misc_relfilenodes(migratorContext *ctx, Cluster whichCluster)
 							"		pg_catalog.pg_namespace n "
 							"WHERE 	c.relnamespace = n.oid AND "
 							"		n.nspname = 'pg_catalog' AND "
-							"		c.relname IN "
-							"		('pg_database', 'pg_largeobject', "
-							"		 'pg_largeobject_loid_pn_index') "
+							"		c.relname = 'pg_database' "
 							"ORDER BY c.relname");
 
 	i_relfile = PQfnumber(res, "relfilenode");
 	if (whichCluster == CLUSTER_OLD)
-	{
 		ctx->old.pg_database_oid = atol(PQgetvalue(res, 0, i_relfile));
-		ctx->old.pg_largeobject_oid = atol(PQgetvalue(res, 1, i_relfile));
-		ctx->old.pg_largeobject_index_oid = atol(PQgetvalue(res, 2, i_relfile));
-	}
 	else
-	{
 		ctx->new.pg_database_oid = atol(PQgetvalue(res, 0, i_relfile));
-		ctx->new.pg_largeobject_oid = atol(PQgetvalue(res, 1, i_relfile));
-		ctx->new.pg_largeobject_index_oid = atol(PQgetvalue(res, 2, i_relfile));
-	}
 
 	PQclear(res);
 	PQfinish(conn);
