@@ -824,7 +824,8 @@ check_for_composite_types(migratorContext *ctx, Cluster whichCluster)
 								"		c.relnamespace = n.oid AND "
 								"		t.typtype = 'c' AND "
 								"		t.oid >= "
-									STRINGIFY(FirstNormalObjectId) " AND "
+/* oids assigned by initdb might change, so use FirstBootstrapObjectId */
+									STRINGIFY(FirstBootstrapObjectId) " AND "
 								"		n.nspname != 'pg_catalog' AND "
 								"		n.nspname != 'information_schema'");
 
@@ -922,7 +923,8 @@ check_for_array_types(migratorContext *ctx, Cluster whichCluster)
 								"			WHERE t2.oid = t.typelem "
 								"		) AND "
 								"		t.oid >= "
-									STRINGIFY(FirstNormalObjectId) " AND "
+/* oids assigned by initdb might change, so use FirstBootstrapObjectId */
+									STRINGIFY(FirstBootstrapObjectId) " AND "
 								"		n.nspname != 'pg_catalog' AND "
 								"		n.nspname != 'information_schema'");
 
@@ -1014,7 +1016,8 @@ check_for_enum_types(migratorContext *ctx, Cluster whichCluster)
 								"		c.relnamespace = n.oid AND "
 								"		t.typtype = 'e' AND "
 								"		t.oid >= "
-									STRINGIFY(FirstNormalObjectId) " AND "
+/* oids assigned by initdb might change, so use FirstBootstrapObjectId */
+									STRINGIFY(FirstBootstrapObjectId) " AND "
 								"		n.nspname != 'pg_catalog' AND "
 								"		n.nspname != 'information_schema'");
 
